@@ -1,11 +1,9 @@
 
 import cv2 as cv
-import Point
-import DetectedArea
-import DetectedFace
-
-import HelperFunctions
-
+from . import Point
+from . import DetectedArea
+from .DetectedArea import DetectedFace
+from .helperFunctions import *
 import numpy as np
 
 
@@ -74,7 +72,7 @@ class ImageManager:
 
         # finding objects in then given angle degree rotated image
        
-        rotatedGrayImage = HelperFunctions.rotateCounterClockwise(self.grayImage, angle)
+        rotatedGrayImage = rotateCounterClockwise(self.grayImage, angle)
             
         # Collecting raw detected objects received from detectMultiScale
         rawObjs = detector.detectMultiScale(rotatedGrayImage, scaleFactor = scaleFactor, minNeighbors = minNeighbors, minSize = minDimensions, maxSize = maxDimensions)
@@ -292,7 +290,7 @@ class ImageManager:
             faceOrigin = Point((leftEye.center.x + rightEye.center.x)/2,(leftEye.center.y + rightEye.center.y)/2)
            
             # Rotate the face origin point and the image such that the face is straightened up
-            rotatedGrayImage = HelperFunctions.rotateClockwise(self.grayImage, relativeCounterClockwiseAngle)
+            rotatedGrayImage = rotateClockwise(self.grayImage, relativeCounterClockwiseAngle)
             rotatedImageCenter = Point(rotatedGrayImage.shape[1]/2, rotatedGrayImage.shape[0]/2)
             rotatedFaceOrigin = faceOrigin.rotatePointClockwise(originalImageCenter, relativeCounterClockwiseAngle)
             rotatedFaceOrigin = rotatedFaceOrigin.projectPoint(originalImageCenter, rotatedImageCenter)
@@ -300,11 +298,11 @@ class ImageManager:
             
             
             # DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- 
-            debugOriginalImage = HelperFunctions.rotateClockwise(self.image, 0)
+            debugOriginalImage = rotateClockwise(self.image, 0)
             leftEye.draw(debugOriginalImage, (255,0,255), 2)
             rightEye.draw(debugOriginalImage, (0,255,255), 2)
             cv.circle(debugOriginalImage, faceOrigin.exportCoordinates(), 0, (0, 255, 0), 20)
-            debugRotatedOriginalImage = HelperFunctions.rotateClockwise(debugOriginalImage, relativeCounterClockwiseAngle)
+            debugRotatedOriginalImage = rotateClockwise(debugOriginalImage, relativeCounterClockwiseAngle)
             cv.circle(debugRotatedOriginalImage, rotatedFaceOrigin.exportCoordinates(), 0, (255, 255, 255), 12)
             # DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- DEBUG step --- 
             
@@ -353,7 +351,7 @@ class ImageManager:
 
             if len(detectedFaces) == 0:
                 # Scan the image upside down in case of upside down faces
-                rotatedCrop = HelperFunctions.rotateClockwise(rotatedCrop, 180)
+                rotatedCrop = rotateClockwise(rotatedCrop, 180)
                 detectedFaces = self.haarcascade_face.detectMultiScale(rotatedCrop, scaleFactor, minNeighbors, minSize = self.HARDCODED_faceMinDimensions, maxSize = self.HARDCODED_faceMaxDimensions)
                 if len(detectedFaces) == 0:
                     continue
@@ -375,7 +373,7 @@ class ImageManager:
                     continue
 
                 # Scan the image upside down in case of upside down faces
-                rotatedCrop = HelperFunctions.rotateClockwise(rotatedCrop, 180)
+                rotatedCrop = rotateClockwise(rotatedCrop, 180)
                 detectedFaces = self.haarcascade_face.detectMultiScale(rotatedCrop, scaleFactor, minNeighbors, minSize = self.HARDCODED_faceMinDimensions, maxSize = self.HARDCODED_faceMaxDimensions)
                 if len(detectedFaces) == 0:
                     continue
@@ -407,7 +405,7 @@ class ImageManager:
 
             # Convert biggestFace coordinates from being in the cropped image to the original image
             biggestFace.draw(debugRotatedCrop, (0, 0, 255), 2)
-            cv.imshow("Potential face " + str(debugPotentialFaceNumber), HelperFunctions.resizeMinTo(debugRotatedCrop, 250))
+            cv.imshow("Potential face " + str(debugPotentialFaceNumber), resizeMinTo(debugRotatedCrop, 250))
 
             debugArrayFaces.append((biggestFace.copy(), rotatedFaceCenter, croppedCenter, rotatedImageCenter, relativeCounterClockwiseAngle, originalImageCenter)) 
                 
@@ -450,7 +448,7 @@ class ImageManager:
             faceOrigin = Point((leftEye.center.x + rightEye.center.x)/2,(leftEye.center.y + rightEye.center.y)/2)
            
             # Rotate the face origin point and the image such that the face is straightened up
-            rotatedGrayImage = HelperFunctions.rotateClockwise(self.grayImage, relativeCounterClockwiseAngle)
+            rotatedGrayImage = rotateClockwise(self.grayImage, relativeCounterClockwiseAngle)
             rotatedImageCenter = Point(rotatedGrayImage.shape[1]/2, rotatedGrayImage.shape[0]/2)
             rotatedFaceOrigin = faceOrigin.rotatePointClockwise(originalImageCenter, relativeCounterClockwiseAngle).projectPoint(originalImageCenter, rotatedImageCenter)
 
@@ -483,7 +481,7 @@ class ImageManager:
             # if found no faces right side up
             if len(detectedFaces) == 0:
                 # Scan the image upside down
-                rotatedCrop = HelperFunctions.rotateClockwise(rotatedCrop, 180)
+                rotatedCrop = rotateClockwise(rotatedCrop, 180)
                 detectedFaces = self.haarcascade_face.detectMultiScale(rotatedCrop, scaleFactor, minNeighbors, minSize = self.HARDCODED_faceMinDimensions, maxSize = self.HARDCODED_faceMaxDimensions)
                 if len(detectedFaces) == 0:
                     continue
@@ -505,7 +503,7 @@ class ImageManager:
                     continue
 
                 # Scan the image upside down in case of upside down faces
-                rotatedCrop = HelperFunctions.rotateClockwise(rotatedCrop, 180)
+                rotatedCrop = rotateClockwise(rotatedCrop, 180)
                 detectedFaces = self.haarcascade_face.detectMultiScale(rotatedCrop, scaleFactor, minNeighbors, minSize = self.HARDCODED_faceMinDimensions, maxSize = self.HARDCODED_faceMaxDimensions)
                 if len(detectedFaces) == 0:
                     continue
